django-crudbuilder : Generic way to create model CRUD — django-crudbuilder 0.1.5 documentation

# django-crudbuilder : Generic way to create model CRUD

## Contents:

- Overview
  - Features
  - Requirements and Compatibility
- Installation and Usage
  - Generating CRUD class based views
  - CRUD class Attributes
- Additional Settings
  - LOGIN_REQUIRED_FOR_CRUD
  - PERMISSION_REQUIRED_FOR_CRUD
- Forms
  - Custom Modelform in CRUD class
  - Separate CREATE and UPDATE forms
  - Inline Formset (Parent child relation)
- Templates
  - Use your own HTML templates for crudbuilder
  - Enable search in ListView template
- Signals
  - post_create_signal
  - post_update_signal
  - post_inline_create_signal
  - post_inline_update_signal

## Issues:

Use the GitHub issue tracker for django-crudbuilder to submit bugs, issues, and feature requests.